package com.ruoyi.project.asset.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.asset.mapper.TSpecdevTypemgrMapper;
import com.ruoyi.project.asset.domain.TSpecdevTypemgr;
import com.ruoyi.project.asset.service.ITSpecdevTypemgrService;

/**
 * 设备类型管理Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-08-08
 */
@Service
public class TSpecdevTypemgrServiceImpl implements ITSpecdevTypemgrService 
{
    @Autowired
    private TSpecdevTypemgrMapper tSpecdevTypemgrMapper;

    /**
     * 查询设备类型管理
     * 
     * @param id 设备类型管理主键
     * @return 设备类型管理
     */
    @Override
    public TSpecdevTypemgr selectTSpecdevTypemgrById(Long id)
    {
        return tSpecdevTypemgrMapper.selectTSpecdevTypemgrById(id);
    }

    /**
     * 查询设备类型管理列表
     * 
     * @param tSpecdevTypemgr 设备类型管理
     * @return 设备类型管理
     */
    @Override
    public List<TSpecdevTypemgr> selectTSpecdevTypemgrList(TSpecdevTypemgr tSpecdevTypemgr)
    {
        return tSpecdevTypemgrMapper.selectTSpecdevTypemgrList(tSpecdevTypemgr);
    }

    /**
     * 新增设备类型管理
     * 
     * @param tSpecdevTypemgr 设备类型管理
     * @return 结果
     */
    @Override
    public int insertTSpecdevTypemgr(TSpecdevTypemgr tSpecdevTypemgr)
    {
        return tSpecdevTypemgrMapper.insertTSpecdevTypemgr(tSpecdevTypemgr);
    }

    /**
     * 修改设备类型管理
     * 
     * @param tSpecdevTypemgr 设备类型管理
     * @return 结果
     */
    @Override
    public int updateTSpecdevTypemgr(TSpecdevTypemgr tSpecdevTypemgr)
    {
        return tSpecdevTypemgrMapper.updateTSpecdevTypemgr(tSpecdevTypemgr);
    }

    /**
     * 批量删除设备类型管理
     * 
     * @param ids 需要删除的设备类型管理主键
     * @return 结果
     */
    @Override
    public int deleteTSpecdevTypemgrByIds(Long[] ids)
    {
        return tSpecdevTypemgrMapper.deleteTSpecdevTypemgrByIds(ids);
    }

    /**
     * 删除设备类型管理信息
     * 
     * @param id 设备类型管理主键
     * @return 结果
     */
    @Override
    public int deleteTSpecdevTypemgrById(Long id)
    {
        return tSpecdevTypemgrMapper.deleteTSpecdevTypemgrById(id);
    }
}
